@@ -102,6 +102,9 @@ INSTALL_PIG_ARG = '--install-pig'
 INSTALL_PIG_NAME = 'Install Pig'
 INSTALL_HIVE_ARG = '--install-hive'
 INSTALL_HIVE_NAME = 'Install Hive'
+HIVE_SITE_KEY = '--hive-site'
+INSTALL_HIVE_SITE_ARG = '--install-hive-site'
+INSTALL_HIVE_SITE_NAME = 'Install Hive Site Configuration'
 BASE_PATH_ARG = '--base-path'
 INSTALL_GANGLIA_NAME = 'Install Ganglia'
 INSTALL_HBASE_NAME = 'Install HBase'
